Documentation
¶
Overview ¶
Package ethconfig contains the configuration of the ETH and LES protocols.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Defaults = Config{ HistoryMode: AllHistory, SyncMode: SnapSync, NetworkId: 0, TxLookupLimit: 2350000, TransactionHistory: 2350000, LogHistory: 2350000, StateHistory: params.FullImmutabilityThreshold, DatabaseCache: 512, TrieCleanCache: 154, TrieDirtyCache: 256, TrieTimeout: 60 * time.Minute, SnapshotCache: 102, FilterLogCacheSize: 32, Miner: miner.DefaultConfig, TxPool: legacypool.DefaultConfig, BlobPool: blobpool.DefaultConfig, RPCGasCap: 50000000, RPCEVMTimeout: 5 * time.Second, GPO: FullNodeGPO, RPCTxFeeCap: 1, }
Defaults contains default settings for use on the Ethereum main net.
var FullNodeGPO = gasprice.Config{ Blocks: 20, Percentile: 60, MaxHeaderHistory: 1024, MaxBlockHistory: 1024, MaxPrice: gasprice.DefaultMaxPrice, IgnorePrice: gasprice.DefaultIgnorePrice, }
FullNodeGPO contains default gasprice oracle settings for full node.
var HistoryPrunePoints = map[common.Hash]*HistoryPrunePoint{ params.MainnetGenesisHash: { BlockNumber: 15537393, BlockHash: common.HexToHash("0x55b11b918355b1ef9c5db810302ebad0bf2544255b530cdce90674d5887bb286"), }, params.SepoliaGenesisHash: { BlockNumber: 1450409, BlockHash: common.HexToHash("0x229f6b18ca1552f1d5146deceb5387333f40dc6275aebee3f2c5c4ece07d02db"), }, }
HistoryPrunePoints contains the pre-defined history pruning cutoff blocks for known networks. They point to the first post-merge block. Any pruning should truncate *up to* but excluding given block.
Functions ¶
func CreateConsensusEngine ¶
CreateConsensusEngine creates a consensus engine for the given chain config. Clique is allowed for now to live standalone, but ethash is forbidden and can only exist on already merged networks.
Types ¶
type Config ¶
type Config struct {
// The genesis block, which is inserted if the database is empty.
// If nil, the Ethereum main net block is used.
Genesis *core.Genesis `toml:",omitempty"`
// Network ID separates blockchains on the peer-to-peer networking level. When left
// zero, the chain ID is used as network ID.
NetworkId uint64
SyncMode SyncMode
// HistoryMode configures chain history retention.
HistoryMode HistoryMode
// This can be set to list of enrtree:// URLs which will be queried for
// nodes to connect to.
EthDiscoveryURLs []string
SnapDiscoveryURLs []string
// State options.
NoPruning bool // Whether to disable pruning and flush everything to disk
NoPrefetch bool // Whether to disable prefetching and only load state on demand
// Deprecated: use 'TransactionHistory' instead.
TxLookupLimit uint64 `toml:",omitempty"` // The maximum number of blocks from head whose tx indices are reserved.
TransactionHistory uint64 `toml:",omitempty"` // The maximum number of blocks from head whose tx indices are reserved.
LogHistory uint64 `toml:",omitempty"` // The maximum number of blocks from head where a log search index is maintained.
LogNoHistory bool `toml:",omitempty"` // No log search index is maintained.
LogExportCheckpoints string // export log index checkpoints to file
StateHistory uint64 `toml:",omitempty"` // The maximum number of blocks from head whose state histories are reserved.
// State scheme represents the scheme used to store ethereum states and trie
// nodes on top. It can be 'hash', 'path', or none which means use the scheme
// consistent with persistent state.
StateScheme string `toml:",omitempty"`
// RequiredBlocks is a set of block number -> hash mappings which must be in the
// canonical chain of all remote peers. Setting the option makes geth verify the
// presence of these blocks for every new peer connection.
RequiredBlocks map[uint64]common.Hash `toml:"-"`
// Database options
SkipBcVersionCheck bool `toml:"-"`
DatabaseHandles int `toml:"-"`
DatabaseCache int
DatabaseFreezer string
TrieCleanCache int
TrieDirtyCache int
TrieTimeout time.Duration
SnapshotCache int
Preimages bool
// This is the number of blocks for which logs will be cached in the filter system.
FilterLogCacheSize int
// Mining options
Miner miner.Config
// Transaction pool options
TxPool legacypool.Config
BlobPool blobpool.Config
// Gas Price Oracle options
GPO gasprice.Config
// Enables tracking of SHA3 preimages in the VM
EnablePreimageRecording bool
// Enables VM tracing
VMTrace string
VMTraceJsonConfig string
// RPCGasCap is the global gas cap for eth-call variants.
RPCGasCap uint64
// RPCEVMTimeout is the global timeout for eth-call.
RPCEVMTimeout time.Duration
// RPCTxFeeCap is the global transaction fee(price * gaslimit) cap for
// send-transaction variants. The unit is ether.
RPCTxFeeCap float64
// OverridePrague (TODO: remove after the fork)
OverridePrague *uint64 `toml:",omitempty"`
// OverrideVerkle (TODO: remove after the fork)
OverrideVerkle *uint64 `toml:",omitempty"`
}
Config contains configuration options for ETH and LES protocols.
func (Config) MarshalTOML ¶
MarshalTOML marshals as TOML.
func (*Config) UnmarshalTOML ¶
UnmarshalTOML unmarshals from TOML.
type HistoryMode ¶ added in v0.1.5
type HistoryMode uint32
HistoryMode configures history pruning.
const ( // AllHistory (default) means that all chain history down to genesis block will be kept. AllHistory HistoryMode = iota // PostMergeHistory sets the history pruning point to the merge activation block. PostMergeHistory )
func (HistoryMode) IsValid ¶ added in v0.1.5
func (m HistoryMode) IsValid() bool
func (HistoryMode) MarshalText ¶ added in v0.1.5
func (m HistoryMode) MarshalText() ([]byte, error)
MarshalText implements encoding.TextMarshaler.
func (HistoryMode) String ¶ added in v0.1.5
func (m HistoryMode) String() string
func (*HistoryMode) UnmarshalText ¶ added in v0.1.5
func (m *HistoryMode) UnmarshalText(text []byte) error
UnmarshalText implements encoding.TextUnmarshaler.
type HistoryPrunePoint ¶ added in v0.1.5
type SyncMode ¶ added in v0.1.5
type SyncMode uint32
SyncMode represents the synchronisation mode of the downloader. It is a uint32 as it is used with atomic operations.